@@ -199,35 +199,34 @@ const Application = new Lang.Class({
         this._window.showMessageUserDialog();
     },
 
+    _savedChannelIndex: function(savedChannels, account, channel) {
+        let accountPath = account.get_object_path();
+        let matchChannel = channel.toLowerCase();
+        for (let i = 0; i < savedChannels.length; i++)
+            if (savedChannels[i].account.deep_unpack() == accountPath &&
+                savedChannels[i].channel.deep_unpack().toLowerCase() == matchChannel)
+                return i;
+        return -1;
+    },
+
     _addSavedChannel: function(account, channel) {
         let savedChannels = this._settings.get_value('saved-channel-list').deep_unpack();
-        let savedChannel = {
+        if (this._savedChannelIndex(savedChannels, account, channel) != -1)
+            return;
+        savedChannels.push({
             account: GLib.Variant.new('s', account.get_object_path()),
             channel: GLib.Variant.new('s', channel)
-        };
-        for (let i = 0; i < savedChannels.length; i++)
-            if (savedChannels[i].account.equal(savedChannel.account) &&
-                savedChannels[i].channel.equal(savedChannel.channel))
-                return;
-        savedChannels.push(savedChannel);
+        });
         this._settings.set_value('saved-channel-list',
                                  GLib.Variant.new('aa{sv}', savedChannels));
     },
 
     _removeSavedChannel: function(account, channel) {
         let savedChannels = this._settings.get_value('saved-channel-list').deep_unpack();
-        let savedChannel = {
-            account: GLib.Variant.new('s', account.get_object_path()),
-            channel: GLib.Variant.new('s', channel)
-        };
-        let i;
-        for (i = 0; i < savedChannels.length; i++)
-            if (savedChannels[i].account.equal(savedChannel.account) &&
-                savedChannels[i].channel.equal(savedChannel.channel))
-                break;
-        if (!savedChannels[i])
+        let pos = this._savedChannelIndex(savedChannels, account, channel);
+        if (pos < 0)
             return;
-        savedChannels.splice(i, 1);
+        savedChannels.splice(pos, 1);
         this._settings.set_value('saved-channel-list',
                                  GLib.Variant.new('aa{sv}', savedChannels));
     },
@@ -442,7 +441,8 @@ const Application = new Lang.Class({
                 'Giovanni Campagna <gcampagna@src.gnome.org>',
                 'Carlos Garnacho <carlosg@gnome.org>',
                 'Jonas Danielsson <jonas.danielsson@threetimestwo.org>',
-                'Bastian Ilsø <bastianilso@gnome.org>'
+                'Bastian Ilsø <bastianilso@gnome.org>',
+                'Kunaal Jain <kunaalus@gmail.com>'
             ],
             artists: [
                 'Sam Hewitt',
@@ -450,8 +450,7 @@ const Application = new Lang.Class({
             ],
             translator_credits: _("translator-credits"),
             comments: _("An Internet Relay Chat Client for GNOME"),
-            copyright: 'Copyright ' + String.fromCharCode(0x00A9) // ©
-                                    + ' 2013 Red Hat, Inc.',
+            copyright: 'Copyright © 2013-2015 The Polari authors',
             license_type: Gtk.License.GPL_2_0,
             logo_icon_name: 'polari',
             version: pkg.version,
