@@ -4,6 +4,7 @@ const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const Pango = imports.gi.Pango;
 const PangoCairo = imports.gi.PangoCairo;
+const Polari = imports.gi.Polari;
 const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
@@ -13,7 +14,6 @@ const Utils = imports.utils;
 
 const MAX_NICK_CHARS = 8;
 const IGNORE_STATUS_TIME = 5;
-const TP_CURRENT_TIME = GLib.MAXUINT32;
 
 const SCROLL_TIMEOUT = 100; // ms
 
@@ -613,8 +613,12 @@ const ChatView = new Lang.Class({
         }
     },
 
+    _getNickTagName: function(nick) {
+        return NICKTAG_PREFIX + Polari.util_get_basenick(nick);
+    },
+
     _setNickStatus: function(nick, status) {
-        let nickTag = this._lookupTag('nick' + nick);
+        let nickTag = this._lookupTag(this._getNickTagName(nick));
         if (!nickTag)
            return;
 
@@ -842,7 +846,7 @@ const ChatView = new Lang.Class({
             let param = GLib.Variant.new('(ssu)',
                                          [ account.get_object_path(),
                                            this._room.channel_name,
-                                           TP_CURRENT_TIME ]);
+                                           Utils.getTpEventTime() ]);
             notification.set_default_action_and_target('app.join-room', param);
             this._app.send_notification('pending-message-' + id, notification);
         }
@@ -910,10 +914,11 @@ const ChatView = new Lang.Class({
         } else {
             if (state.lastNick != message.nick) {
                 let tags = [this._lookupTag('nick')];
-                let nickTag = this._lookupTag(NICKTAG_PREFIX + message.nick);
+                let nickTagName = this._getNickTagName(message.nick);
+                let nickTag = this._lookupTag(nickTagName);
 
                 if (!nickTag) {
-                    nickTag = new Gtk.TextTag({ name: NICKTAG_PREFIX + message.nick });
+                    nickTag = new Gtk.TextTag({ name: nickTagName });
                     this._view.get_buffer().get_tag_table().add(nickTag);
                 }
                 tags.push(nickTag);
