@@ -19,6 +19,7 @@
 #include <string.h>
 
 #include "polari-room.h"
+#include "polari-util.h"
 
 typedef struct _PolariRoomPrivate PolariRoomPrivate;
 
@@ -108,12 +109,18 @@ polari_create_room_id (TpAccount    *account,
                        const char   *name,
                        TpHandleType  type)
 {
+  char *id, *folded_name;
+
   g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
   g_return_val_if_fail (name != NULL, NULL);
 
-  return g_strdup_printf ("%s/%d/%s",
-                          tp_proxy_get_object_path (TP_PROXY (account)),
-                          type, name);
+  folded_name = g_utf8_strdown (name, -1);
+  id = g_strdup_printf ("%s/%d/%s",
+                        tp_proxy_get_object_path (TP_PROXY (account)),
+                        type, folded_name);
+
+  g_free (folded_name);
+  return id;
 }
 
 gboolean
@@ -123,8 +130,9 @@ polari_room_should_highlight_message (PolariRoom *room,
   PolariRoomPrivate *priv;
   TpConnection *conn;
   TpContact *self;
-  char *text;
-  gboolean result;
+  char *text, *match;
+  gboolean result = FALSE;
+  int len;
 
   g_return_val_if_fail (POLARI_IS_ROOM (room), FALSE);
 
@@ -142,7 +150,23 @@ polari_room_should_highlight_message (PolariRoom *room,
     return FALSE;
 
   text = tp_message_to_text (message, NULL);
-  result = strstr(text, priv->self_nick) != NULL;
+  len = strlen (priv->self_nick);
+  match = strstr (text, priv->self_nick);
+
+  while (match != NULL)
+    {
+      gboolean starts_word, ends_word;
+
+      /* assume ASCII nicknames, so no complex pango-style breaks */
+      starts_word = (match == text || g_ascii_isspace (*(match - 1)));
+      ends_word = !g_ascii_isalnum (*(match + len));
+
+      result = starts_word && ends_word;
+      if (result)
+        break;
+      match = strstr (match + len, priv->self_nick);
+    }
+
   g_free (text);
 
   return result;
@@ -240,8 +264,6 @@ update_self_nick (PolariRoom *room)
 {
   TpConnection *conn;
   TpContact *self;
-  const char *nick;
-  int len;
 
   PolariRoomPrivate *priv = room->priv;
 
@@ -253,25 +275,17 @@ update_self_nick (PolariRoom *room)
   conn = tp_channel_get_connection (room->priv->channel);
   self = tp_connection_get_self_contact (conn);
 
-  nick = tp_contact_get_alias (self);
-  len = strlen (nick);
-  do
-    if (g_ascii_isalnum (nick[len - 1]))
-        break;
-  while (--len > 0);
-
-  priv->self_nick = g_strndup (nick, len);
+  priv->self_nick = polari_util_get_basenick (tp_contact_get_alias (self));
 }
 
 static void
-update_identifier (PolariRoom *room)
+set_display_name (PolariRoom *room,
+                  const char *display_name)
 {
   PolariRoomPrivate *priv = room->priv;
 
-  g_clear_pointer (&priv->display_name, g_free);
-  if (priv->channel_name)
-    priv->display_name = g_strdup (priv->channel_name +
-                                   (priv->channel_name[0] == '#' ? 1 : 0));
+  g_free (priv->display_name);
+  priv->display_name = g_strdup (display_name);
 
   g_object_notify_by_pspec (G_OBJECT (room), props[PROP_DISPLAY_NAME]);
 }
@@ -494,11 +508,26 @@ polari_room_set_channel_name (PolariRoom *room,
 
   priv = room->priv;
 
-  if (priv->channel_name)
-    g_free (priv->channel_name);
-  priv->channel_name = g_strdup (channel_name);
+  g_free (priv->channel_name);
 
-  update_identifier (room);
+  if (channel_name)
+    {
+      /* Tp enforces lower-case for all channel names[0], so we need to either
+       * convert the name to lower-case once here or each time we compare it to
+       * a channel identifier in check_channel(); case isn't relevant for the
+       * display name on the other hand, so we can use the original string which
+       * matches what the user requested.
+       *
+       * [0] http://cgit.freedesktop.org/telepathy/telepathy-idle/tree/src/idle-handles.c#n158
+       */
+      priv->channel_name = g_utf8_strdown (channel_name, -1);
+      set_display_name (room, channel_name + (channel_name[0] == '#' ? 1 : 0));
+    }
+  else
+    {
+      priv->channel_name = NULL;
+      set_display_name (room, NULL);
+    }
 
   g_object_notify_by_pspec (G_OBJECT (room), props[PROP_CHANNEL_NAME]);
 }
@@ -514,7 +543,7 @@ check_channel (PolariRoom *room,
 
   account = tp_connection_get_account (tp_channel_get_connection (channel));
   return account == priv->account &&
-         g_strcmp0 (tp_channel_get_identifier (channel), priv->channel_name) == 0;
+         strcmp (tp_channel_get_identifier (channel), priv->channel_name) == 0;
 }
 
 static void
