@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * Copyright (C) 2013 Red Hat, Inc.
+ * Copyright (C) 2015 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -18,16 +18,26 @@
 
 #include "polari-util.h"
 
+#include <glib.h>
+
 /**
- * polari_util_get_clipboard_for_widget:
- * @widget: (transfer none): a #GtkWidget
+ * polari_util_get_basenick:
+ * @nick: (transfer none): the original nick
  *
- * Get the GDK_SELECTION_CLIPBOARD clipboard for @widget.
- *
- * Returns: (transfer none): a #GtkClipboard
+ * Returns: (transfer full): the "base nick" of @nick, which can be used to
+ *   group nicks that likely belong to the same person (e.g. "nick-away" or
+ *   "nick|bbl")
  */
-GtkClipboard *
-polari_util_get_clipboard_for_widget (GtkWidget *widget)
+char *
+polari_util_get_basenick (const char *nick)
 {
-  return gtk_widget_get_clipboard (widget, GDK_SELECTION_CLIPBOARD);
+  int len;
+
+  for (len = 0; g_ascii_isalnum(nick[len]); len++)
+    ;
+
+  if (len > 0)
+    return g_strndup (nick, len);
+  else
+    return g_strdup (nick);
 }
