@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
- * Copyright (C) 2013 Red Hat, Inc.
+ * Copyright (C) 2015 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -19,8 +19,6 @@
 #ifndef __POLARI_UTIL_H__
 #define __POLARI_UTIL_H__
 
-#include <gtk/gtk.h>
-
-GtkClipboard *polari_util_get_clipboard_for_widget (GtkWidget *widget);
+char *polari_util_get_basenick (const char *nick);
 
 #endif /* __POLARI_UTIL_H__ */
