@@ -5,9 +5,10 @@ const Tp = imports.gi.TelepathyGLib;
 const Tpl = imports.gi.TelepathyLogger;
 
 const AccountsMonitor = imports.accountsMonitor;
+const ChatroomManager = imports.chatroomManager;
 const Lang = imports.lang;
+const Utils = imports.utils;
 
-const TP_CURRENT_TIME = GLib.MAXUINT32;
 const MAX_RECENT_USERS = 5;
 
 const MessageDialog = new Lang.Class({
@@ -19,6 +20,8 @@ const MessageDialog = new Lang.Class({
         this._settings = new Gio.Settings({ schema_id: 'org.gnome.Polari' });
 
         this._accounts = {};
+        this._roomManager = ChatroomManager.getDefault();
+
         AccountsMonitor.getDefault().dupAccounts().forEach(Lang.bind(this,
             function(a) {
                 if (!a.enabled)
@@ -34,11 +37,10 @@ const MessageDialog = new Lang.Class({
             this._connectionCombo.append_text(names[i]);
         this._connectionCombo.sensitive = names.length > 1;
 
-        let factory = Tp.AccountManager.dup().get_factory();
-        let lastUsed = factory.ensure_account(this._settings.get_string('last-used-account'), []);
+        let activeRoom = this._roomManager.getActiveRoom();
         let activeIndex = 0;
-        if (lastUsed)
-            activeIndex = Math.max(names.indexOf(lastUsed.display_name), 0);
+        if(activeRoom)
+            activeIndex = Math.max(names.indexOf(activeRoom.account.display_name), 0);
         this._connectionCombo.set_active(activeIndex);
 
         this._updateCanConfirm();
@@ -167,9 +169,6 @@ const MessageDialog = new Lang.Class({
         let selected = this._connectionCombo.get_active_text();
         let account = this._accounts[selected];
 
-        this._settings.set_string('last-used-account',
-                                  account.get_object_path());
-
         let user = this._nameEntry.get_text();
 
         let app = Gio.Application.get_default();
@@ -177,7 +176,7 @@ const MessageDialog = new Lang.Class({
         action.activate(GLib.Variant.new('(ssu)',
                                          [ account.get_object_path(),
                                            user,
-                                           TP_CURRENT_TIME ]));
+                                           Utils.getTpEventTime() ]));
     },
 
     _updateCanConfirm: function() {
