@@ -146,7 +146,8 @@ const RoomListHeader = new Lang.Class({
                        'iconStack',
                        'errorPopover',
                        'popoverLabel',
-                       'popoverButton'],
+                       'popoverButton',
+                       'spinner'],
 
     _init: function(params) {
         this._account = params.account;
@@ -183,6 +184,15 @@ const RoomListHeader = new Lang.Class({
 
     _onDisplayNameChanged: function() {
         this._label.label = this._account.display_name;
+
+        let parent;
+        do
+          parent = this.get_parent();
+        while (parent && !(parent instanceof Gtk.ListBox));
+
+        if (parent)
+          parent.invalidate_sort();
+
         let accessibleName = _("Connection %s has an error").format(this._account.display_name);
         this.get_accessible().set_name(accessibleName);
     },
@@ -260,6 +270,7 @@ const RoomListHeader = new Lang.Class({
         }
         this.sensitive = isError;
         this._iconStack.visible_child_name = child;
+        this._spinner.active = (child == 'connecting');
     },
 });
 
